"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.IndexSettingsManager = void 0;
var _errors = require("../errors");
class IndexSettingsManager {
  constructor(elasticsearch) {
    this.elasticsearch = elasticsearch;
  }
  async getSettings(index) {
    try {
      const response = await this.elasticsearch.indices.getSettings({
        index
      });
      const setting = response.body[index].settings.index;
      return {
        numberOfReplicas: setting.number_of_replicas,
        refreshInterval: setting.refresh_interval
      };
    } catch (ex) {
      throw new _errors.IndexSettingsGetError(ex, index);
    }
  }
  async setSettings(index, settings) {
    try {
      await this.elasticsearch.indices.putSettings({
        index,
        body: {
          index: {
            number_of_replicas: settings.numberOfReplicas,
            refresh_interval: settings.refreshInterval
          }
        }
      });
    } catch (ex) {
      throw new _errors.IndexSettingsSetError(ex, index);
    }
  }
}
exports.IndexSettingsManager = IndexSettingsManager;

//# sourceMappingURL=IndexSettingsManager.js.map